import { IIoK8sApiAuthorizationV1FieldSelectorAttributes } from "./FieldSelectorAttributes";
import { IIoK8sApiAuthorizationV1LabelSelectorAttributes } from "./LabelSelectorAttributes";
import { ModelData, Model } from "@kubernetes-models/base";
/**
 * ResourceAttributes includes the authorization attributes available for resource requests to the Authorizer interface
 */
export interface IResourceAttributes {
    /**
     * fieldSelector describes the limitation on access based on field.  It can only limit access, not broaden it.
     *
     * This field  is alpha-level. To use this field, you must enable the `AuthorizeWithSelectors` feature gate (disabled by default).
     */
    "fieldSelector"?: IIoK8sApiAuthorizationV1FieldSelectorAttributes;
    /**
     * Group is the API Group of the Resource.  "\*" means all.
     */
    "group"?: string;
    /**
     * labelSelector describes the limitation on access based on labels.  It can only limit access, not broaden it.
     *
     * This field  is alpha-level. To use this field, you must enable the `AuthorizeWithSelectors` feature gate (disabled by default).
     */
    "labelSelector"?: IIoK8sApiAuthorizationV1LabelSelectorAttributes;
    /**
     * Name is the name of the resource being requested for a "get" or deleted for a "delete". "" (empty) means all.
     */
    "name"?: string;
    /**
     * Namespace is the namespace of the action being requested.  Currently, there is no distinction between no namespace and all namespaces "" (empty) is defaulted for LocalSubjectAccessReviews "" (empty) is empty for cluster-scoped resources "" (empty) means "all" for namespace scoped resources from a SubjectAccessReview or SelfSubjectAccessReview
     */
    "namespace"?: string;
    /**
     * Resource is one of the existing resource types.  "\*" means all.
     */
    "resource"?: string;
    /**
     * Subresource is one of the existing resource types.  "" means none.
     */
    "subresource"?: string;
    /**
     * Verb is a kubernetes resource API verb, like: get, list, watch, create, update, delete, proxy.  "\*" means all.
     */
    "verb"?: string;
    /**
     * Version is the API Version of the Resource.  "\*" means all.
     */
    "version"?: string;
}
/**
 * ResourceAttributes includes the authorization attributes available for resource requests to the Authorizer interface
 */
export declare class ResourceAttributes extends Model<IResourceAttributes> implements IResourceAttributes {
    "fieldSelector"?: IIoK8sApiAuthorizationV1FieldSelectorAttributes;
    "group"?: string;
    "labelSelector"?: IIoK8sApiAuthorizationV1LabelSelectorAttributes;
    "name"?: string;
    "namespace"?: string;
    "resource"?: string;
    "subresource"?: string;
    "verb"?: string;
    "version"?: string;
    constructor(data?: ModelData<IResourceAttributes>);
}
export { IResourceAttributes as IIoK8sApiAuthorizationV1ResourceAttributes, ResourceAttributes as IoK8sApiAuthorizationV1ResourceAttributes };
