import { IIoK8sApiAutoscalingV2beta2ContainerResourceMetricSource } from "./ContainerResourceMetricSource";
import { IIoK8sApiAutoscalingV2beta2ExternalMetricSource } from "./ExternalMetricSource";
import { IIoK8sApiAutoscalingV2beta2ObjectMetricSource } from "./ObjectMetricSource";
import { IIoK8sApiAutoscalingV2beta2PodsMetricSource } from "./PodsMetricSource";
import { IIoK8sApiAutoscalingV2beta2ResourceMetricSource } from "./ResourceMetricSource";
import { ModelData, Model } from "@kubernetes-models/base";
/**
 * MetricSpec specifies how to scale based on a single metric (only `type` and one other matching field should be set at once).
 */
export interface IMetricSpec {
    /**
     * container resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing a single container in each pod of the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source. This is an alpha feature and can be enabled by the HPAContainerMetrics feature flag.
     */
    "containerResource"?: IIoK8sApiAutoscalingV2beta2ContainerResourceMetricSource;
    /**
     * external refers to a global metric that is not associated with any Kubernetes object. It allows autoscaling based on information coming from components running outside of cluster (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster).
     */
    "external"?: IIoK8sApiAutoscalingV2beta2ExternalMetricSource;
    /**
     * object refers to a metric describing a single kubernetes object (for example, hits-per-second on an Ingress object).
     */
    "object"?: IIoK8sApiAutoscalingV2beta2ObjectMetricSource;
    /**
     * pods refers to a metric describing each pod in the current scale target (for example, transactions-processed-per-second).  The values will be averaged together before being compared to the target value.
     */
    "pods"?: IIoK8sApiAutoscalingV2beta2PodsMetricSource;
    /**
     * resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing each pod in the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.
     */
    "resource"?: IIoK8sApiAutoscalingV2beta2ResourceMetricSource;
    /**
     * type is the type of metric source.  It should be one of "ContainerResource", "External", "Object", "Pods" or "Resource", each mapping to a matching field in the object. Note: "ContainerResource" type is available on when the feature-gate HPAContainerMetrics is enabled
     */
    "type": string;
}
/**
 * MetricSpec specifies how to scale based on a single metric (only `type` and one other matching field should be set at once).
 */
export declare class MetricSpec extends Model<IMetricSpec> implements IMetricSpec {
    "containerResource"?: IIoK8sApiAutoscalingV2beta2ContainerResourceMetricSource;
    "external"?: IIoK8sApiAutoscalingV2beta2ExternalMetricSource;
    "object"?: IIoK8sApiAutoscalingV2beta2ObjectMetricSource;
    "pods"?: IIoK8sApiAutoscalingV2beta2PodsMetricSource;
    "resource"?: IIoK8sApiAutoscalingV2beta2ResourceMetricSource;
    "type": string;
    constructor(data?: ModelData<IMetricSpec>);
}
export { IMetricSpec as IIoK8sApiAutoscalingV2beta2MetricSpec, MetricSpec as IoK8sApiAutoscalingV2beta2MetricSpec };
