import { IIoK8sApiDiscoveryV1Endpoint } from "./Endpoint";
import { IIoK8sApimachineryPkgApisMetaV1ObjectMeta } from "@kubernetes-models/apimachinery/apis/meta/v1/ObjectMeta";
import { IIoK8sApiDiscoveryV1EndpointPort } from "./EndpointPort";
import { ModelData, TypeMeta, Model } from "@kubernetes-models/base";
/**
 * EndpointSlice represents a set of service endpoints. Most EndpointSlices are created by the EndpointSlice controller to represent the Pods selected by Service objects. For a given service there may be multiple EndpointSlice objects which must be joined to produce the full set of endpoints; you can find all of the slices for a given service by listing EndpointSlices in the service's namespace whose `kubernetes.io/service-name` label contains the service's name.
 */
export interface IEndpointSlice extends TypeMeta {
    /**
     * addressType specifies the type of address carried by this EndpointSlice. All addresses in this slice must be the same type. This field is immutable after creation. The following address types are currently supported: \* IPv4: Represents an IPv4 Address. \* IPv6: Represents an IPv6 Address. \* FQDN: Represents a Fully Qualified Domain Name. (Deprecated) The EndpointSlice controller only generates, and kube-proxy only processes, slices of addressType "IPv4" and "IPv6". No semantics are defined for the "FQDN" type.
     *
     * Possible enum values:
     *  - `"FQDN"` represents a FQDN.
     *  - `"IPv4"` represents an IPv4 Address.
     *  - `"IPv6"` represents an IPv6 Address.
     */
    "addressType": "FQDN" | "IPv4" | "IPv6";
    "apiVersion": "discovery.k8s.io/v1";
    /**
     * endpoints is a list of unique endpoints in this slice. Each slice may include a maximum of 1000 endpoints.
     */
    "endpoints": Array<IIoK8sApiDiscoveryV1Endpoint>;
    "kind": "EndpointSlice";
    /**
     * Standard object's metadata.
     */
    "metadata"?: IIoK8sApimachineryPkgApisMetaV1ObjectMeta;
    /**
     * ports specifies the list of network ports exposed by each endpoint in this slice. Each port must have a unique name. Each slice may include a maximum of 100 ports. Services always have at least 1 port, so EndpointSlices generated by the EndpointSlice controller will likewise always have at least 1 port. EndpointSlices used for other purposes may have an empty ports list.
     */
    "ports"?: Array<IIoK8sApiDiscoveryV1EndpointPort>;
}
/**
 * EndpointSlice represents a set of service endpoints. Most EndpointSlices are created by the EndpointSlice controller to represent the Pods selected by Service objects. For a given service there may be multiple EndpointSlice objects which must be joined to produce the full set of endpoints; you can find all of the slices for a given service by listing EndpointSlices in the service's namespace whose `kubernetes.io/service-name` label contains the service's name.
 */
export declare class EndpointSlice extends Model<IEndpointSlice> implements IEndpointSlice {
    "addressType": "FQDN" | "IPv4" | "IPv6";
    "apiVersion": IEndpointSlice["apiVersion"];
    "endpoints": Array<IIoK8sApiDiscoveryV1Endpoint>;
    "kind": IEndpointSlice["kind"];
    "metadata"?: IIoK8sApimachineryPkgApisMetaV1ObjectMeta;
    "ports"?: Array<IIoK8sApiDiscoveryV1EndpointPort>;
    static apiVersion: IEndpointSlice["apiVersion"];
    static kind: IEndpointSlice["kind"];
    static is: import("@kubernetes-models/base").TypeMetaGuard<IEndpointSlice>;
    constructor(data?: ModelData<IEndpointSlice>);
}
export { IEndpointSlice as IIoK8sApiDiscoveryV1EndpointSlice, EndpointSlice as IoK8sApiDiscoveryV1EndpointSlice };
