import { IIoK8sApimachineryPkgApisMetaV1LabelSelector } from "@kubernetes-models/apimachinery/apis/meta/v1/LabelSelector";
import { IIoK8sApiCoreV1PodTemplateSpec } from "../../v1/PodTemplateSpec";
import { IIoK8sApiExtensionsV1beta1DaemonSetUpdateStrategy } from "./DaemonSetUpdateStrategy";
import { ModelData, Model } from "@kubernetes-models/base";
/**
 * DaemonSetSpec is the specification of a daemon set.
 */
export interface IDaemonSetSpec {
    /**
     * The minimum number of seconds for which a newly created DaemonSet pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready).
     */
    "minReadySeconds"?: number;
    /**
     * The number of old history to retain to allow rollback. This is a pointer to distinguish between explicit zero and not specified. Defaults to 10.
     */
    "revisionHistoryLimit"?: number;
    /**
     * A label query over pods that are managed by the daemon set. Must match in order to be controlled. If empty, defaulted to labels on Pod template. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
     */
    "selector"?: IIoK8sApimachineryPkgApisMetaV1LabelSelector;
    /**
     * An object that describes the pod that will be created. The DaemonSet will create exactly one copy of this pod on every node that matches the template's node selector (or on every node if no node selector is specified). More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#pod-template
     */
    "template": IIoK8sApiCoreV1PodTemplateSpec;
    /**
     * DEPRECATED. A sequence number representing a specific generation of the template. Populated by the system. It can be set only during the creation.
     */
    "templateGeneration"?: number;
    /**
     * An update strategy to replace existing DaemonSet pods with new pods.
     */
    "updateStrategy"?: IIoK8sApiExtensionsV1beta1DaemonSetUpdateStrategy;
}
/**
 * DaemonSetSpec is the specification of a daemon set.
 */
export declare class DaemonSetSpec extends Model<IDaemonSetSpec> implements IDaemonSetSpec {
    "minReadySeconds"?: number;
    "revisionHistoryLimit"?: number;
    "selector"?: IIoK8sApimachineryPkgApisMetaV1LabelSelector;
    "template": IIoK8sApiCoreV1PodTemplateSpec;
    "templateGeneration"?: number;
    "updateStrategy"?: IIoK8sApiExtensionsV1beta1DaemonSetUpdateStrategy;
    constructor(data?: ModelData<IDaemonSetSpec>);
}
export { IDaemonSetSpec as IIoK8sApiExtensionsV1beta1DaemonSetSpec, DaemonSetSpec as IoK8sApiExtensionsV1beta1DaemonSetSpec };
