import { IIoK8sApiNetworkingV1beta1IngressBackend } from "./IngressBackend";
import { IIoK8sApiNetworkingV1beta1IngressRule } from "./IngressRule";
import { IIoK8sApiNetworkingV1beta1IngressTLS } from "./IngressTLS";
import { ModelData, Model } from "@kubernetes-models/base";
/**
 * IngressSpec describes the Ingress the user wishes to exist.
 */
export interface IIngressSpec {
    /**
     * A default backend capable of servicing requests that don't match any rule. At least one of 'backend' or 'rules' must be specified. This field is optional to allow the loadbalancer controller or defaulting logic to specify a global default.
     */
    "backend"?: IIoK8sApiNetworkingV1beta1IngressBackend;
    /**
     * IngressClassName is the name of the IngressClass cluster resource. The associated IngressClass defines which controller will implement the resource. This replaces the deprecated `kubernetes.io/ingress.class` annotation. For backwards compatibility, when that annotation is set, it must be given precedence over this field. The controller may emit a warning if the field and annotation have different values. Implementations of this API should ignore Ingresses without a class specified. An IngressClass resource may be marked as default, which can be used to set a default value for this field. For more information, refer to the IngressClass documentation.
     */
    "ingressClassName"?: string;
    /**
     * A list of host rules used to configure the Ingress. If unspecified, or no rule matches, all traffic is sent to the default backend.
     */
    "rules"?: Array<IIoK8sApiNetworkingV1beta1IngressRule>;
    /**
     * TLS configuration. Currently the Ingress only supports a single TLS port, 443. If multiple members of this list specify different hosts, they will be multiplexed on the same port according to the hostname specified through the SNI TLS extension, if the ingress controller fulfilling the ingress supports SNI.
     */
    "tls"?: Array<IIoK8sApiNetworkingV1beta1IngressTLS>;
}
/**
 * IngressSpec describes the Ingress the user wishes to exist.
 */
export declare class IngressSpec extends Model<IIngressSpec> implements IIngressSpec {
    "backend"?: IIoK8sApiNetworkingV1beta1IngressBackend;
    "ingressClassName"?: string;
    "rules"?: Array<IIoK8sApiNetworkingV1beta1IngressRule>;
    "tls"?: Array<IIoK8sApiNetworkingV1beta1IngressTLS>;
    constructor(data?: ModelData<IIngressSpec>);
}
export { IIngressSpec as IIoK8sApiNetworkingV1beta1IngressSpec, IngressSpec as IoK8sApiNetworkingV1beta1IngressSpec };
