import { ModelData, Model } from "@kubernetes-models/base";
/**
 * PolicyRule holds information that describes a policy rule, but does not contain information about who the rule applies to or which namespace the rule applies to.
 */
export interface IPolicyRule {
    /**
     * APIGroups is the name of the APIGroup that contains the resources.  If multiple API groups are specified, any action requested against one of the enumerated resources in any API group will be allowed.
     */
    "apiGroups"?: Array<string>;
    /**
     * NonResourceURLs is a set of partial urls that a user should have access to.  \*s are allowed, but only as the full, final step in the path Since non-resource URLs are not namespaced, this field is only applicable for ClusterRoles referenced from a ClusterRoleBinding. Rules can either apply to API resources (such as "pods" or "secrets") or non-resource URL paths (such as "/api"),  but not both.
     */
    "nonResourceURLs"?: Array<string>;
    /**
     * ResourceNames is an optional white list of names that the rule applies to.  An empty set means that everything is allowed.
     */
    "resourceNames"?: Array<string>;
    /**
     * Resources is a list of resources this rule applies to.  '\*' represents all resources in the specified apiGroups. '\*\/foo' represents the subresource 'foo' for all resources in the specified apiGroups.
     */
    "resources"?: Array<string>;
    /**
     * Verbs is a list of Verbs that apply to ALL the ResourceKinds and AttributeRestrictions contained in this rule.  VerbAll represents all kinds.
     */
    "verbs": Array<string>;
}
/**
 * PolicyRule holds information that describes a policy rule, but does not contain information about who the rule applies to or which namespace the rule applies to.
 */
export declare class PolicyRule extends Model<IPolicyRule> implements IPolicyRule {
    "apiGroups"?: Array<string>;
    "nonResourceURLs"?: Array<string>;
    "resourceNames"?: Array<string>;
    "resources"?: Array<string>;
    "verbs": Array<string>;
    constructor(data?: ModelData<IPolicyRule>);
}
export { IPolicyRule as IIoK8sApiRbacV1beta1PolicyRule, PolicyRule as IoK8sApiRbacV1beta1PolicyRule };
