import { IIoK8sApiCoreV1ObjectFieldSelector } from "./ObjectFieldSelector";
import { IIoK8sApiCoreV1ResourceFieldSelector } from "./ResourceFieldSelector";
import { ModelData, Model } from "@kubernetes-models/base";
/**
 * DownwardAPIVolumeFile represents information to create the file containing the pod field
 */
export interface IDownwardAPIVolumeFile {
    /**
     * Required: Selects a field of the pod: only annotations, labels, name, namespace and uid are supported.
     */
    "fieldRef"?: IIoK8sApiCoreV1ObjectFieldSelector;
    /**
     * Optional: mode bits used to set permissions on this file, must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     */
    "mode"?: number;
    /**
     * Required: Path is  the relative path name of the file to be created. Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
     */
    "path": string;
    /**
     * Selects a resource of the container: only resources limits and requests (limits.cpu, limits.memory, requests.cpu and requests.memory) are currently supported.
     */
    "resourceFieldRef"?: IIoK8sApiCoreV1ResourceFieldSelector;
}
/**
 * DownwardAPIVolumeFile represents information to create the file containing the pod field
 */
export declare class DownwardAPIVolumeFile extends Model<IDownwardAPIVolumeFile> implements IDownwardAPIVolumeFile {
    "fieldRef"?: IIoK8sApiCoreV1ObjectFieldSelector;
    "mode"?: number;
    "path": string;
    "resourceFieldRef"?: IIoK8sApiCoreV1ResourceFieldSelector;
    constructor(data?: ModelData<IDownwardAPIVolumeFile>);
}
export { IDownwardAPIVolumeFile as IIoK8sApiCoreV1DownwardAPIVolumeFile, DownwardAPIVolumeFile as IoK8sApiCoreV1DownwardAPIVolumeFile };
