import { ModelData, Model } from "@kubernetes-models/base";
/**
 * PersistentVolumeClaimVolumeSource references the user's PVC in the same namespace. This volume finds the bound PV and mounts that volume for the pod. A PersistentVolumeClaimVolumeSource is, essentially, a wrapper around another type of volume that is owned by someone else (the system).
 */
export interface IPersistentVolumeClaimVolumeSource {
    /**
     * claimName is the name of a PersistentVolumeClaim in the same namespace as the pod using this volume. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistentvolumeclaims
     */
    "claimName": string;
    /**
     * readOnly Will force the ReadOnly setting in VolumeMounts. Default false.
     */
    "readOnly"?: boolean;
}
/**
 * PersistentVolumeClaimVolumeSource references the user's PVC in the same namespace. This volume finds the bound PV and mounts that volume for the pod. A PersistentVolumeClaimVolumeSource is, essentially, a wrapper around another type of volume that is owned by someone else (the system).
 */
export declare class PersistentVolumeClaimVolumeSource extends Model<IPersistentVolumeClaimVolumeSource> implements IPersistentVolumeClaimVolumeSource {
    "claimName": string;
    "readOnly"?: boolean;
    constructor(data?: ModelData<IPersistentVolumeClaimVolumeSource>);
}
export { IPersistentVolumeClaimVolumeSource as IIoK8sApiCoreV1PersistentVolumeClaimVolumeSource, PersistentVolumeClaimVolumeSource as IoK8sApiCoreV1PersistentVolumeClaimVolumeSource };
