import { IIoK8sApiCoreV1WeightedPodAffinityTerm } from "./WeightedPodAffinityTerm";
import { IIoK8sApiCoreV1PodAffinityTerm } from "./PodAffinityTerm";
import { ModelData, Model } from "@kubernetes-models/base";
/**
 * Pod affinity is a group of inter pod affinity scheduling rules.
 */
export interface IPodAffinity {
    /**
     * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
     */
    "preferredDuringSchedulingIgnoredDuringExecution"?: Array<IIoK8sApiCoreV1WeightedPodAffinityTerm>;
    /**
     * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
     */
    "requiredDuringSchedulingIgnoredDuringExecution"?: Array<IIoK8sApiCoreV1PodAffinityTerm>;
}
/**
 * Pod affinity is a group of inter pod affinity scheduling rules.
 */
export declare class PodAffinity extends Model<IPodAffinity> implements IPodAffinity {
    "preferredDuringSchedulingIgnoredDuringExecution"?: Array<IIoK8sApiCoreV1WeightedPodAffinityTerm>;
    "requiredDuringSchedulingIgnoredDuringExecution"?: Array<IIoK8sApiCoreV1PodAffinityTerm>;
    constructor(data?: ModelData<IPodAffinity>);
}
export { IPodAffinity as IIoK8sApiCoreV1PodAffinity, PodAffinity as IoK8sApiCoreV1PodAffinity };
