import { ModelData, Model } from "@kubernetes-models/base";
/**
 * PodResourceClaimStatus is stored in the PodStatus for each PodResourceClaim which references a ResourceClaimTemplate. It stores the generated name for the corresponding ResourceClaim.
 */
export interface IPodResourceClaimStatus {
    /**
     * Name uniquely identifies this resource claim inside the pod. This must match the name of an entry in pod.spec.resourceClaims, which implies that the string must be a DNS_LABEL.
     */
    "name": string;
    /**
     * ResourceClaimName is the name of the ResourceClaim that was generated for the Pod in the namespace of the Pod. If this is unset, then generating a ResourceClaim was not necessary. The pod.spec.resourceClaims entry can be ignored in this case.
     */
    "resourceClaimName"?: string;
}
/**
 * PodResourceClaimStatus is stored in the PodStatus for each PodResourceClaim which references a ResourceClaimTemplate. It stores the generated name for the corresponding ResourceClaim.
 */
export declare class PodResourceClaimStatus extends Model<IPodResourceClaimStatus> implements IPodResourceClaimStatus {
    "name": string;
    "resourceClaimName"?: string;
    constructor(data?: ModelData<IPodResourceClaimStatus>);
}
export { IPodResourceClaimStatus as IIoK8sApiCoreV1PodResourceClaimStatus, PodResourceClaimStatus as IoK8sApiCoreV1PodResourceClaimStatus };
