import { IIoK8sApiCoreV1ClusterTrustBundleProjection } from "./ClusterTrustBundleProjection";
import { IIoK8sApiCoreV1ConfigMapProjection } from "./ConfigMapProjection";
import { IIoK8sApiCoreV1DownwardAPIProjection } from "./DownwardAPIProjection";
import { IIoK8sApiCoreV1SecretProjection } from "./SecretProjection";
import { IIoK8sApiCoreV1ServiceAccountTokenProjection } from "./ServiceAccountTokenProjection";
import { ModelData, Model } from "@kubernetes-models/base";
/**
 * Projection that may be projected along with other supported volume types. Exactly one of these fields must be set.
 */
export interface IVolumeProjection {
    /**
     * ClusterTrustBundle allows a pod to access the `.spec.trustBundle` field of ClusterTrustBundle objects in an auto-updating file.
     *
     * Alpha, gated by the ClusterTrustBundleProjection feature gate.
     *
     * ClusterTrustBundle objects can either be selected by name, or by the combination of signer name and a label selector.
     *
     * Kubelet performs aggressive normalization of the PEM contents written into the pod filesystem.  Esoteric PEM features such as inter-block comments and block headers are stripped.  Certificates are deduplicated. The ordering of certificates within the file is arbitrary, and Kubelet may change the order over time.
     */
    "clusterTrustBundle"?: IIoK8sApiCoreV1ClusterTrustBundleProjection;
    /**
     * configMap information about the configMap data to project
     */
    "configMap"?: IIoK8sApiCoreV1ConfigMapProjection;
    /**
     * downwardAPI information about the downwardAPI data to project
     */
    "downwardAPI"?: IIoK8sApiCoreV1DownwardAPIProjection;
    /**
     * secret information about the secret data to project
     */
    "secret"?: IIoK8sApiCoreV1SecretProjection;
    /**
     * serviceAccountToken is information about the serviceAccountToken data to project
     */
    "serviceAccountToken"?: IIoK8sApiCoreV1ServiceAccountTokenProjection;
}
/**
 * Projection that may be projected along with other supported volume types. Exactly one of these fields must be set.
 */
export declare class VolumeProjection extends Model<IVolumeProjection> implements IVolumeProjection {
    "clusterTrustBundle"?: IIoK8sApiCoreV1ClusterTrustBundleProjection;
    "configMap"?: IIoK8sApiCoreV1ConfigMapProjection;
    "downwardAPI"?: IIoK8sApiCoreV1DownwardAPIProjection;
    "secret"?: IIoK8sApiCoreV1SecretProjection;
    "serviceAccountToken"?: IIoK8sApiCoreV1ServiceAccountTokenProjection;
    constructor(data?: ModelData<IVolumeProjection>);
}
export { IVolumeProjection as IIoK8sApiCoreV1VolumeProjection, VolumeProjection as IoK8sApiCoreV1VolumeProjection };
